@@ -219,13 +219,11 @@ class Strategy(base_strategy.BaseStrategy):
                                     self.trader.log(
                                         f"获取遗留仓位symbol的instrument信息失败: {pos['symbol']} - {e}", level="WARN", color="yellow")
 
-            # 配置 self.statistics 的余额
-            if not self.statistics.start_balance:
-                init_available_balance, init_balance = self.get_total_init_balance()
-                self.statistics.start_balance = init_balance
-                self.statistics.max_balance = init_balance
-                self.statistics.now_balance = init_balance
-                self.statistics.today_balance = init_balance
+            init_available_balance, init_balance = self.get_total_init_balance()
+            self.statistics.start_balance = init_balance
+            self.statistics.today_start_balance = init_balance
+            self.statistics.max_balance = init_balance
+            self.statistics.now_balance = init_balance
 
             # 设置杠杆 和 全仓模式
             self.trader.log(f"设置杠杆倍数: {self.leverage}x",
@@ -292,7 +290,7 @@ class Strategy(base_strategy.BaseStrategy):
                 "sub": {
                     "SubscribeTimer": {
                         "update_interval": {"secs": 5, "nanos": 0},
-                        "name": "update_exchange_balance",  # 每 60 秒进行一次交易所余额更新
+                        "name": "update_exchange_balance",  # 每 5 秒进行一次交易所余额更新
                     }
                 }
             },
@@ -394,6 +392,15 @@ class Strategy(base_strategy.BaseStrategy):
                 self.balances[idx]['balance'] for idx in range(self.base_index))
             self.statistics.update_balance(
                 self.statistics.now_balance)
+            self.trader.log(f"账户起始资金：{self.statistics.start_balance}, 账户当日起始资金: {self.statistics.today_start_balance}，当前资金：{self.statistics.now_balance}, 最高资金: {self.statistics.max_balance}", level="INFO", color="blue", web=False)
+
+    def get_total_init_balance(self):
+        total_available_balance = 0
+        total_balance = 0
+        for i in self.balances:
+            total_available_balance += i['available_balance']
+            total_balance += i['balance']
+        return (total_available_balance, total_balance)
 
 # ============================= 下单函数 ====================================
 
