@@ -82,11 +82,17 @@ class Strategy(base_strategy.BaseStrategy):
 
         # 交易对行情存储
         self.bbo = [{} for _ in range(self.base_index)]
+        self.fundings = [
+            {symbol: {"funding_rate": 0, "funding_interval": 8,
+                        "next_funding_at": 0} for symbol in self.symbols[idx]}
+            for idx in range(self.base_index)
+        ]
 
         # 账户变量
         self.balances = [{} for _ in range(self.base_index)]
         self.pm = HedgePositionManager(self.symbols[0], self.base_index)
         self.statistics = Statistics()
+        self.order_manager = OrderManager()
 
     def prepare_symbols(self):
         try:
@@ -211,13 +217,11 @@ class Strategy(base_strategy.BaseStrategy):
                                     self.trader.log(
                                         f"获取遗留仓位symbol的instrument信息失败: {pos['symbol']} - {e}", level="WARN", color="yellow")
 
-            # 配置 self.statistics 的余额
-            if not self.statistics.start_balance:
-                init_available_balance, init_balance = self.get_total_init_balance()
-                self.statistics.start_balance = init_balance
-                self.statistics.max_balance = init_balance
-                self.statistics.now_balance = init_balance
-                self.statistics.today_balance = init_balance
+            init_available_balance, init_balance = self.get_total_init_balance()
+            self.statistics.start_balance = init_balance
+            self.statistics.today_start_balance = init_balance
+            self.statistics.max_balance = init_balance
+            self.statistics.now_balance = init_balance
 
             # 设置杠杆 和 全仓模式
             self.trader.log(f"设置杠杆倍数: {self.leverage}x",
@@ -245,6 +249,7 @@ class Strategy(base_strategy.BaseStrategy):
                     if "Ok" in res:
                         self.trader.log(
                             f"设置杠杆和全仓模式: {res}", level="INFO", color="blue")
+
         except Exception as e:
             self.trader.log(
                 f"策略启动失败: {traceback.format_exc()}", level="ERROR", color="red")
@@ -282,8 +287,18 @@ class Strategy(base_strategy.BaseStrategy):
             {
                 "sub": {
                     "SubscribeTimer": {
-                        "update_interval": {"secs": 60, "nanos": 0},
-                        "name": "update_web_timer",  # 每 60 秒进行一次 WEB 页面更新
+                        "update_interval": {"secs": 5, "nanos": 0},
+                        "name": "update_exchange_balance",  # 每 5 秒进行一次交易所余额更新
+                    }
+                }
+            },
+        )
+        subs.append(
+            {
+                "sub": {
+                    "SubscribeTimer": {
+                        "update_interval": {"secs": 3, "nanos": 0},
+                        "name": "global_risk_check",  # 每 5 秒进行一次全局风控检查
                     }
                 }
             },
@@ -296,7 +311,7 @@ class Strategy(base_strategy.BaseStrategy):
         symbol = bbo["symbol"]
         if bbo['timestamp'] <= self.exchange_timestamp[index][symbol]:
             return
-        
+
         self.bbo[index][symbol] = [
             bbo['bid_price'],
             bbo['bid_qty'],
@@ -324,6 +339,11 @@ class Strategy(base_strategy.BaseStrategy):
         ]
         self.exchange_timestamp[index][symbol] = depth["timestamp"]
 
+        risk_signal = self.risk_manager.check_tick_risk()
+        if risk_signal and not risk_signal.is_empty():
+            print(f"行情延迟异常: {risk_signal.to_dict()}")
+            print(f"---------------------------------------------------------")
+
     def on_balance(self, account_id, balances):
         usdt = next((x for x in balances if x["asset"] == "USDT"), None)
         self.balances[account_id].update(usdt)
@@ -340,6 +360,14 @@ class Strategy(base_strategy.BaseStrategy):
     def on_timer_subscribe(self, timer_name):
         pass
 
+    def get_total_init_balance(self):
+        total_available_balance = 0
+        total_balance = 0
+        for i in self.balances:
+            total_available_balance += i['available_balance']
+            total_balance += i['balance']
+        return (total_available_balance, total_balance)
+
 # ============================= 下单函数 ====================================
 
     def place_market_order(self, cid, local_order):
