@@ -84,10 +84,17 @@ class Strategy(base_strategy.BaseStrategy):
 
         # 交易对行情存储
         self.bbo = [{} for _ in range(self.base_index)]
+        self.fundings = [
+            {symbol: {"funding_rate": 0, "funding_interval": 8,
+                        "next_funding_at": 0} for symbol in self.symbols[idx]}
+            for idx in range(self.base_index)
+        ]
 
         # 账户变量
         self.balances = [{} for _ in range(self.base_index)]
-        self.has_pos = False
+        self.pm = HedgePositionManager(self.symbols[0], self.base_index)
+        self.statistics = Statistics()
+        self.order_manager = OrderManager()
 
     def prepare_symbols(self):
         try:
@@ -212,13 +219,11 @@ class Strategy(base_strategy.BaseStrategy):
                                     self.trader.log(
                                         f"获取遗留仓位symbol的instrument信息失败: {pos['symbol']} - {e}", level="WARN", color="yellow")
 
-            # 配置 self.statistics 的余额
-            if not self.statistics.start_balance:
-                init_available_balance, init_balance = self.get_total_init_balance()
-                self.statistics.start_balance = init_balance
-                self.statistics.max_balance = init_balance
-                self.statistics.now_balance = init_balance
-                self.statistics.today_balance = init_balance
+            init_available_balance, init_balance = self.get_total_init_balance()
+            self.statistics.start_balance = init_balance
+            self.statistics.today_start_balance = init_balance
+            self.statistics.max_balance = init_balance
+            self.statistics.now_balance = init_balance
 
             # 设置杠杆 和 全仓模式
             self.trader.log(f"设置杠杆倍数: {self.leverage}x",
@@ -246,6 +251,7 @@ class Strategy(base_strategy.BaseStrategy):
                     if "Ok" in res:
                         self.trader.log(
                             f"设置杠杆和全仓模式: {res}", level="INFO", color="blue")
+
         except Exception as e:
             self.trader.log(
                 f"策略启动失败: {traceback.format_exc()}", level="ERROR", color="red")
@@ -354,6 +360,14 @@ class Strategy(base_strategy.BaseStrategy):
                 print(f"global_risk_check 风控告警: {risk_signal.to_dict()}")
                 print(f"---------------------------------------------------------")
 
+    def get_total_init_balance(self):
+        total_available_balance = 0
+        total_balance = 0
+        for i in self.balances:
+            total_available_balance += i['available_balance']
+            total_balance += i['balance']
+        return (total_available_balance, total_balance)
+
 # ============================= 创建仓位函数 ====================================
     def create_position(self, index, symbol):
         cid = order_cid = self.trader.create_cid(self.ex_map[index])
