@@ -15,8 +15,8 @@ def bbo_latency_check(
     taker_bbo = bbo[0]
     maker_bbo = bbo[1]
     
-    taker_timestamp = taker_bbo.get('timestamp', 0)
-    maker_timestamp = maker_bbo.get('timestamp', 0)
+    taker_timestamp = taker_bbo[4]
+    maker_timestamp = maker_bbo[4]
 
     current_timestamp = int(time.time() * 1000)
 
